# Aneki
Random russian jokes (especially about computer and etc) from several sites in your terminal  

![](https://github.com/VolkovAK/aneki/workflows/Build/badge.svg)  

## Usage  
Installation:

    pip3 install aneki

Usage:

    aneki

Test is everything OK:

    aneki -t

## Dependencies
Project tested on Python 3.5 - 3.8 for Ubuntu 16.04 - 18.04.  
Project have single dependency - "requests"

## Sites
Currently (11.01.2020) next sites are supported:
 - bash.im ![](https://github.com/VolkovAK/aneki/workflows/BashIm/badge.svg)  
 - anekdot.ru ![](https://github.com/VolkovAK/aneki/workflows/AnekdotRu/badge.svg)  
 - nekdo.ru ![](https://github.com/VolkovAK/aneki/workflows/NekdoRu/badge.svg)  
 - shytok.net ![](https://github.com/VolkovAK/aneki/workflows/ShytokNet/badge.svg)  

Next sites won't be supported:
 - anekdotov.net - not funny IMHO
 - pikabu.ru, ithappens.me - too long stories
